(sec_tsbrowse_docs_mainpage)=

# Tsbrowse documentation  

This is the documentation for tsbrowse, an open-source Python package for visualising ARGs in the [tskit](https://tskit.dev/tskit/docs/) tree sequence format.  

## Contents  
### Getting started  
This section includes an introduction to tsbrowse, and notes on how to install and use the app.  
    [Introduction](intro.md)  
    [Installing tsbrowse](install.md)  
### Pages  
This section provides an overview of the various pages displayed in the webapp.  
    [Overview](overview.md)  
    [Tables](tables.md)  
    [Mutations](mutations.md)  
    [Edges](edges.md)  
    [Nodes](nodes.md)  
    [Trees](trees.md)  
### Extras  
Feedback and bug reports are welcome. This section contains information on contributing and engaging with the tskit community.  
    [Contributing](contributing.md)  
    [Changelog](CHANGELOG.md)  
    [Community](https://tskit.dev/community/)  
